# XML Resource Viewer

A modern web application for viewing and interacting with XML resources, specifically designed for HL7 FHIR XML files. The application automatically detects new XML files, processes them, and provides a user-friendly interface for viewing and temporarily modifying the data.

## Features

- Automatic detection and processing of XML files
- Dynamic mapping of XML structures to JSON
- Interactive web interface for viewing XML resources
- Support for nested XML elements and attributes
- Real-time updates when new files are added
- Temporary data manipulation capabilities

## Setup

### Backend (Python/Flask)

1. Navigate to the server directory:
   ```bash
   cd server
   ```

2. Create and activate a virtual environment:
   ```bash
   python -m venv venv
   source venv/bin/activate  # On Windows: venv\Scripts\activate
   ```

3. Install dependencies:
   ```bash
   pip install -r requirements.txt
   ```

4. Create the XML files directory:
   ```bash
   mkdir xml_files
   ```

5. Start the server:
   ```bash
   python main.py
   ```

### Frontend (React/Vite)

1. Navigate to the client directory:
   ```bash
   cd client
   ```

2. Install dependencies:
   ```bash
   npm install
   ```

3. Start the development server:
   ```bash
   npm run dev
   ```

## Usage

1. Place your XML files in the `server/xml_files` directory
2. Access the web interface at `http://localhost:5173`
3. Select a resource from the list to view its contents
4. Interact with the data using the provided input fields

## Development

### Backend Structure

- `main.py`: Flask server and API endpoints
- `xml_processor.py`: XML file watching and processing logic
- `xml_files/`: Directory for XML resources

### Frontend Structure

- `src/components/XMLResourceList.jsx`: Resource selection component
- `src/components/XMLResourceViewer.jsx`: Resource viewing component
- `src/App.jsx`: Main application component

## Future Enhancements

- Persistent data modification capabilities
- Data type validation in the frontend
- Change history tracking
- Advanced search and filtering
- Export capabilities

## Contributing

1. Fork the repository
2. Create a feature branch
3. Commit your changes
4. Push to the branch
5. Create a Pull Request 