import { useState } from 'react'
import XMLResourceList from './components/XMLResourceList'
import XMLStructureViewer from './components/XMLStructureViewer'
import './App.css'

function App() {
  const [selectedResource, setSelectedResource] = useState(null);
  const [resourceData, setResourceData] = useState(null);
  const [loading, setLoading] = useState(false);
  const [error, setError] = useState(null);

  const handleResourceSelect = async (resourceKey) => {
    try {
      setLoading(true);
      setError(null);
      setSelectedResource(resourceKey);

      const response = await fetch(`http://localhost:8080/api/resources/${resourceKey}/structure`);
      if (!response.ok) {
        throw new Error('Failed to fetch resource structure');
      }

      const data = await response.json();
      setResourceData(data);
    } catch (err) {
      setError(err.message);
    } finally {
      setLoading(false);
    }
  };

  return (
    <div className="min-h-screen bg-gray-100">
      <header className="bg-white shadow">
        <div className="max-w-7xl mx-auto py-6 px-4">
          <h1 className="text-3xl font-bold text-gray-900">
            FHIR Resource Structure Viewer
          </h1>
        </div>
      </header>

      <main className="max-w-7xl mx-auto py-6 sm:px-6 lg:px-8">
        <div className="grid grid-cols-1 md:grid-cols-3 gap-6">
          <div className="md:col-span-1">
            <XMLResourceList onSelectResource={handleResourceSelect} />
          </div>
          <div className="md:col-span-2">
            {loading ? (
              <div className="p-4 bg-white rounded-lg shadow">
                <p className="text-gray-500">Loading resource structure...</p>
              </div>
            ) : error ? (
              <div className="p-4 bg-white rounded-lg shadow">
                <p className="text-red-500">Error: {error}</p>
              </div>
            ) : resourceData ? (
              <XMLStructureViewer xmlContent={resourceData.structure} />
            ) : (
              <div className="p-4 bg-white rounded-lg shadow">
                <p className="text-gray-500">
                  Select a resource from the list to view its structure.
                </p>
              </div>
            )}
          </div>
        </div>
      </main>
    </div>
  )
}

export default App
