import React, { useState, useEffect } from 'react';
import PropTypes from 'prop-types';

const XMLResourceList = ({ onSelectResource }) => {
  const [resources, setResources] = useState([]);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);

  useEffect(() => {
    const fetchResources = async () => {
      try {
        setLoading(true);
        const response = await fetch('http://localhost:8080/api/resources');
        
        if (!response.ok) {
          throw new Error('Failed to fetch resources');
        }

        const data = await response.json();
        setResources(data.resources);
        setError(null);
      } catch (err) {
        setError(err.message);
      } finally {
        setLoading(false);
      }
    };

    fetchResources();
    
    // Poll for new resources every 5 seconds
    const interval = setInterval(fetchResources, 5000);
    return () => clearInterval(interval);
  }, []);

  if (loading && resources.length === 0) {
    return <div className="p-4">Loading resources...</div>;
  }

  if (error) {
    return <div className="p-4 text-red-500">Error: {error}</div>;
  }

  if (resources.length === 0) {
    return (
      <div className="p-4 text-gray-500">
        No XML resources found. Add XML files to the server's xml_files directory to get started.
      </div>
    );
  }

  return (
    <div className="p-4">
      <h2 className="text-xl font-bold mb-4">Available Resources</h2>
      <div className="grid gap-4">
        {resources.map((resource) => (
          <button
            key={resource.key}
            onClick={() => onSelectResource(resource.key)}
            className="p-4 bg-white rounded-lg shadow hover:shadow-md transition-shadow text-left"
          >
            <div className="font-semibold">{resource.resourceType}</div>
            <div className="text-sm text-gray-600">{resource.filename}</div>
          </button>
        ))}
      </div>
    </div>
  );
};

XMLResourceList.propTypes = {
  onSelectResource: PropTypes.func.isRequired,
};

export default XMLResourceList; 