import React, { useState } from 'react';
import PropTypes from 'prop-types';

const XMLStructureViewer = ({ xmlContent }) => {
  const [formData, setFormData] = useState({});

  const getCardinality = (comment) => {
    const match = comment?.match(/(0|1)\.\.(\*|0|1)/);
    return match ? match[0] : '';
  };

  const renderElement = (element) => {
    const { tag, children = [], comments = [], description } = element;
    const cardinality = comments?.length > 0 ? getCardinality(comments[0]) : '';

    return (
      <div key={tag} style={{ marginBottom: '4px' }}>
        {cardinality && (
          <div style={{ 
            display: 'grid',
            gridTemplateColumns: '200px 300px 80px',
            alignItems: 'center',
            gap: '12px',
            padding: '4px 0'
          }}>
            <span style={{ 
              fontFamily: 'monospace',
              fontSize: '14px',
              color: '#2d3748'
            }}>
              {tag}
            </span>
            <input 
              type="text"
              value={formData[tag] || ''}
              onChange={(e) => setFormData(prev => ({ ...prev, [tag]: e.target.value }))}
              placeholder={description || ''}
              title={description || ''}
              style={{ 
                padding: '6px 12px',
                border: '1px solid #e2e8f0',
                borderRadius: '4px',
                width: '100%',
                fontSize: '14px',
                backgroundColor: '#fff',
                transition: 'all 0.2s',
                outline: 'none',
                '::placeholder': {
                  color: '#a0aec0',
                  fontSize: '13px'
                }
              }}
              onFocus={(e) => e.target.style.borderColor = '#4299e1'}
              onBlur={(e) => e.target.style.borderColor = '#e2e8f0'}
            />
            <span style={{ 
              color: '#718096',
              fontSize: '13px',
              fontFamily: 'monospace'
            }}>
              ({cardinality})
            </span>
          </div>
        )}
        
        {children?.length > 0 && (
          <div style={{ 
            marginLeft: '24px',
            paddingLeft: '12px',
            borderLeft: '1px solid #e2e8f0'
          }}>
            {children.map((child, index) => renderElement(child))}
          </div>
        )}
      </div>
    );
  };

  return (
    <div style={{ 
      backgroundColor: '#fff',
      padding: '20px',
      borderRadius: '8px',
      boxShadow: '0 1px 3px rgba(0,0,0,0.1)'
    }}>
      <h2 style={{
        fontSize: '24px',
        fontWeight: '600',
        color: '#2d3748',
        marginTop: '0',
        marginBottom: '20px'
      }}>
        {xmlContent.tag} Resource
      </h2>
      <form onSubmit={(e) => e.preventDefault()}>
        {renderElement(xmlContent)}
      </form>
    </div>
  );
};

XMLStructureViewer.propTypes = {
  xmlContent: PropTypes.shape({
    tag: PropTypes.string.isRequired,
    children: PropTypes.array,
    comments: PropTypes.arrayOf(PropTypes.string),
    description: PropTypes.string
  }).isRequired
};

export default XMLStructureViewer; 