from flask import Blueprint, jsonify, request
from app.services.hl7_service import HL7Service

hl7_bp = Blueprint('hl7', __name__)
hl7_service = HL7Service()

@hl7_bp.route('/api/hl7/messages', methods=['GET'])
def get_messages():
    """Get all received HL7 messages."""
    messages = hl7_service.get_messages()
    return jsonify(messages)

@hl7_bp.route('/api/hl7/messages/<message_id>', methods=['GET'])
def get_message(message_id):
    """Get a specific HL7 message by ID."""
    message = hl7_service.get_message(message_id)
    if message:
        return jsonify(message)
    return jsonify({'error': 'Message not found'}), 404

@hl7_bp.route('/api/hl7/convert/<message_id>', methods=['POST'])
def convert_to_fhir(message_id):
    """Convert an HL7 message to FHIR format."""
    try:
        fhir_resource = hl7_service.convert_to_fhir(message_id)
        return jsonify(fhir_resource)
    except Exception as e:
        return jsonify({'error': str(e)}), 500 