from flask import Blueprint, jsonify, request
from app.services.xml_service import XMLService

xml_bp = Blueprint('xml', __name__)
xml_service = XMLService()

@xml_bp.route('/api/xml/resources', methods=['GET'])
def get_resources():
    """Get all available XML resources."""
    resources = xml_service.get_resources()
    return jsonify(resources)

@xml_bp.route('/api/xml/resources/<resource_key>', methods=['GET'])
def get_resource(resource_key):
    """Get a specific XML resource by key."""
    resource = xml_service.get_resource(resource_key)
    if resource:
        return jsonify(resource)
    return jsonify({'error': 'Resource not found'}), 404

@xml_bp.route('/api/xml/resources/<resource_key>/structure', methods=['GET'])
def get_resource_structure(resource_key):
    """Get the structure of a specific XML resource."""
    structure = xml_service.get_resource_structure(resource_key)
    if structure:
        return jsonify(structure)
    return jsonify({'error': 'Resource structure not found'}), 404 