import os
from app.utils.hl7_receiver import HL7Receiver
from app.utils.hl7_to_fhir_converter import HL7ToFHIRConverter

class HL7Service:
    def __init__(self):
        self.receiver = HL7Receiver()
        self.converter = HL7ToFHIRConverter()
        self.messages_dir = os.path.join(os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__)))), 
                                       'received_messages')

    def get_messages(self):
        """Get all received HL7 messages."""
        messages = []
        for filename in os.listdir(self.messages_dir):
            if filename.endswith('.txt'):
                with open(os.path.join(self.messages_dir, filename), 'r') as f:
                    content = f.read()
                    messages.append({
                        'id': filename,
                        'content': content
                    })
        return messages

    def get_message(self, message_id):
        """Get a specific HL7 message by ID."""
        filepath = os.path.join(self.messages_dir, message_id)
        if os.path.exists(filepath):
            with open(filepath, 'r') as f:
                return {
                    'id': message_id,
                    'content': f.read()
                }
        return None

    def convert_to_fhir(self, message_id):
        """Convert an HL7 message to FHIR format."""
        message = self.get_message(message_id)
        if not message:
            raise ValueError(f"Message {message_id} not found")
        
        return self.converter.convert(message['content']) 