import os
from app.utils.xml_processor import XMLStructureParser

class XMLService:
    def __init__(self):
        self.processor = XMLStructureParser()
        self.xml_dir = os.path.join(os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__)))),
                                   'xml_files')
        self._resources = {}

    def get_resources(self):
        """Get all available XML resources."""
        resources = {}
        for filename in os.listdir(self.xml_dir):
            if filename.endswith('.xml'):
                resource_key = os.path.splitext(filename)[0]
                resources[resource_key] = {
                    'filename': filename,
                    'path': os.path.join(self.xml_dir, filename)
                }
        return resources

    def get_resource(self, resource_key):
        """Get a specific XML resource by key."""
        filepath = os.path.join(self.xml_dir, f"{resource_key}.xml")
        if os.path.exists(filepath):
            return self.processor.parse_xml_file(filepath)
        return None

    def get_resource_structure(self, resource_key):
        """Get the structure of a specific XML resource."""
        resource = self.get_resource(resource_key)
        if resource:
            return resource.get('structure', {})
        return None 