import os
from dotenv import load_dotenv

# Load environment variables from .env file
load_dotenv()

class Config:
    """Base configuration."""
    SECRET_KEY = os.getenv('SECRET_KEY', 'dev')
    DEBUG = False
    TESTING = False
    XML_FILES_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'xml_files')
    RECEIVED_MESSAGES_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'received_messages')
    MESSAGE_LOGS_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'message_logs')

class DevelopmentConfig(Config):
    """Development configuration."""
    DEBUG = True

class TestingConfig(Config):
    """Testing configuration."""
    TESTING = True
    DEBUG = True

class ProductionConfig(Config):
    """Production configuration."""
    DEBUG = False

# Configuration dictionary
config = {
    'development': DevelopmentConfig,
    'testing': TestingConfig,
    'production': ProductionConfig,
    'default': DevelopmentConfig
} 